export const labelSAMLConfiguration = 'SAML configuration';
export const labelDefineSAMLConfiguration = 'Define SAML configuration';
export const labelFailedToSaveSAMLConfiguration =
  'Failed to save SAML configuration';
export const labelSAMLConfigurationSaved = 'SAML configuration saved';
export const labelRequired = 'Required';
export const labelInvalidURL = 'Invalid URL';
export const labelEnableSAMLAuthentication = 'Enable SAMLv2 authentication';
export const labelSAMLOnly = 'SAML only';
export const labelRemoteLoginUrl = 'Remote login URL';
export const labelEntityIdURL = 'Issuer (Entity ID) URL';
export const labelCertificate = 'Copy/paste x.509 certificate';
export const labelUserIdAttribute =
  'User ID (login) attribute for Centreon user';
export const labelEmailAttribute = 'Email attribute';
export const labelFullNameAttribute = 'Full name attribute';
export const labelDefineRelationBetweenRolesAndAclAccessGroups =
  'Define relations between roles and ACL access groups';

export const labelLogoutFrom = 'Logout from';
export const labelLogoutUrl = 'Logout URL';
export const labelCentreonUIOnly = 'Centreon UI only';
export const labelBothIdentityProviderAndCentreonUI =
  'Both identity provider and Centreon UI';
export const labelRequestedAuthnContext = 'Requested authentication context';
export const labelMinimum = 'Minimum';
export const labelExact = 'Exact';
export const labelBetter = 'Better';
export const labelMaximum = 'Maximum';
